# django-osm-field

[![No Maintenance Intended](https://img.shields.io/badge/No%20Maintenance%20Intended-x-red.svg?style=for-the-badge)](http://unmaintained.tech/)
[![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/MarkusH/django-osm-field/Test%20&%20Deploy/main?style=for-the-badge)](https://github.com/MarkusH/django-osm-field/actions?query=branch%3Amain+event%3Apush)
[![Codecov branch](https://img.shields.io/codecov/c/gh/MarkusH/django-osm-field/main?style=for-the-badge)](https://app.codecov.io/gh/MarkusH/django-osm-field/branch/main)
[![Version](https://img.shields.io/pypi/v/django-osm-field?label=Version&style=for-the-badge)](https://pypi.org/project/django-osm-field/)
![License](https://img.shields.io/pypi/l/django-osm-field?style=for-the-badge)
![Python Versions](https://img.shields.io/pypi/pyversions/django-osm-field?label=Python&style=for-the-badge)
![Django Versions](https://img.shields.io/pypi/djversions/django-osm-field?color=%230C4B33&label=Django&style=for-the-badge)
[![Read the Docs](https://img.shields.io/readthedocs/django-osm-field?style=for-the-badge)](https://django-osm-field.readthedocs.io/)

An OpenStreetMap field for Django.

Documentation: https://django-osm-field.readthedocs.io/
